cluster

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 4, 2020 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(parent *dot.Graph, id string, attrs ...Attribute) *dot.Graph

New create a new cluster with the specified attributes.

Types

type Attribute

type Attribute func(*dot.Graph)

Attribute is a function that apply a property to a cluster.

func BottomTop added in v0.4.0

func BottomTop(bt bool) Attribute

BottomTop sets the label location according to layout.

func FontColor

func FontColor(color string) Attribute

FontColor specify the text color.

func FontName

func FontName(name string) Attribute

FontName specify the font used for text.

func FontSize

func FontSize(size float32) Attribute

FontSize specify the font size, in points, used for text.

func Label

func Label(label string) Attribute

Label is the cluster caption.

func PenColor

func PenColor(color string) Attribute

PenColor set the color used to draw the bounding box around a cluster.

Jump to